STANNIX Community


Manual: lsipc

LSIPC(1)						User Commands						    LSIPC(1)

NAME
       lsipc - show information on IPC facilities currently employed in the system

SYNOPSIS
       lsipc [options]

DESCRIPTION
       lsipc shows information on the POSIX and System V inter-process communication facilities for which the calling
       process has read access.

       The default output, as well as the default output from options with predefined output columns (like --shmems, etc.),
       is subject to change. So whenever possible, you should avoid using default outputs in your scripts. Always explicitly
       define expected columns by using --output columns-list in environments where a stable output is required.

OPTIONS
       -i, --id id
	   Show full details on just the one resource element (System V) identified by id. This option needs to be combined
	   with one of the three resource options: -m, -q or -s. It is possible to override the default output format for
	   this option with the --list, --raw, --json or --export option.

       -N, --name name
	   Show full details on just the one resource element (POSIX) identified by name. This option needs to be combined
	   with one of the three resource options: -M, -Q or -S. It is possible to override the default output format for
	   this option with the --list, --raw, --json or --export option.

       -g, --global
	   Show system-wide usage and limits of IPC resources. This option may be combined with one of the three resource
	   options: -m, -q or -s. The default is to show information about all resources.

       -h, --help
	   Display help text and exit.

       -V, --version
	   Display version and exit.

   Resource options
       -m, --shmems
	   Write information about active System V shared memory segments.

       -M, --posix-shmems
	   Write information about active POSIX shared memory segments.

       -q, --queues
	   Write information about active System V message queues.

       -Q, --posix-mqueues
	   Write information about active POSIX message queues.

       -s, --semaphores
	   Write information about active System V semaphore sets.

       -S, --posix-semaphores
	   Write information about active POSIX named semaphores.

   Output formatting
       -c, --creator
	   Show creator and owner.

       -e, --export
	   Produce output in the form of key="value" pairs. All potentially unsafe value characters are hex-escaped
	   (\x). See also option --shell.

       -J, --json
	   Use the JSON output format.

       -l, --list
	   Use the list output format. This is the default, except when --id is used.

       -n, --newline
	   Display each piece of information on a separate line.

       --noheadings
	   Do not print a header line.

       --notruncate
	   Don’t truncate output.

       -o, --output list
	   Specify which output columns to print. Use --help to get a list of all supported columns.

       -b, --bytes
	   Print size in bytes rather than in human readable format.

       -r, --raw
	   Raw output (no columnation).

       -t, --time
	   Write time information. The time of the last control operation that changed the access permissions for all
	   facilities, the time of the last msgsnd(2) and msgrcv(2) operations on message queues, the time of the last
	   shmat(2) and shmdt(2) operations on shared memory, and the time of the last semop(2) operation on semaphores.

       --time-format type
	   Display dates in short, full or iso format. The default is short, this time format is designed to be space
	   efficient and human readable.

       -P, --numeric-perms
	   Print numeric permissions in PERMS column.

       -y, --shell
	   The column name will be modified to contain only characters allowed for shell variable identifiers. This is
	   usable, for example, with --export. Note that this feature has been automatically enabled for --export in version
	   2.37, but due to compatibility issues, now it’s necessary to request this behavior by --shell.

EXIT STATUS
       0
	   if OK,

       1
	   if incorrect arguments specified,

       2
	   if a serious error occurs.

HISTORY
       The lsipc utility is inspired by the ipcs(1) utility.

AUTHORS
       Ondrej Oprala , Karel Zak 

SEE ALSO
       ipcmk(1), ipcrm(1), msgrcv(2), msgsnd(2), semget(2), semop(2), shmat(2), shmdt(2), shmget(2), sysvipc(7)

REPORTING BUGS
       For bug reports, use the issue tracker .

AVAILABILITY
       The lsipc command is part of the util-linux package which can be downloaded from Linux Kernel Archive
       .

util-linux 2.41.3					 2025-12-15						    LSIPC(1)